# -*- coding: utf-8 -*-

"""BASE ROUTINES.

This module contains submodules for basic operations such as type
transformations and adjustments to the default output of Numpy functions.

:Author: Samuel Farrens <samuel.farrens@cea.fr>

"""

__all__ = ['np_adjust', 'transform', 'types', 'wrappers', 'observable']
